#!/bin/bash

# Bash shell script for generating self-signed certs. Run this in a folder, as it
# generates a few files. Large portions of this script were taken from the
# following artcile:
#
# http://usrportage.de/archives/919-Batch-generating-SSL-certificates.html
#
# Additional alterations by: Brad Landers
# Date: 2012-01-27

# Script accepts a single argument, the fqdn for the cert
#DOMAIN="$1"

# DOMAIN="OfficeMaster Gate"

HOSTNAME="$(cat /etc/hostname | awk '{print tolower($0)}')"
DOMAIN="$(cat /etc/resolv.conf | grep search | sed 's/search //g')"
DOMAIN="$HOSTNAME.$DOMAIN"

if [ -z "$DOMAIN" ]; then
  echo "Usage: $(basename $0) <domain>"
  exit 11
fi

fail_if_error() {
  [ $1 != 0 ] && {
    echo "some error has occured when trying to generate certificate"
    echo $1
    unset PASSPHRASE
    exit 10
  }
}

# Certificate details;
subj="
O=Ferrari electronic AG
commonName=$DOMAIN
"

openssl req -x509 -nodes -sha256 -days 3650 -newkey rsa:2048 -keyout /data/key.pem -out /data/cert.pem -subj "$(echo -n "$subj" | tr "\n" "/")"
fail_if_error $?